<?php
/**
 * Event Section options
 *
 * @package Theme Palace
 * @subpackage Edufication Pro
 * @since Edufication Pro 1.0.0
 */

// Add Event section
$wp_customize->add_section( 'edufication_pro_event_section', array(
	'title'             => esc_html__( 'Events','edufication-pro' ),
	'description'       => esc_html__( 'Events Section options.', 'edufication-pro' ),
	'panel'             => 'edufication_pro_front_page_panel',
) );

// Event content enable control and setting
$wp_customize->add_setting( 'edufication_pro_theme_options[event_section_enable]', array(
	'default'			=> 	$options['event_section_enable'],
	'sanitize_callback' => 'edufication_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Edufication_Pro_Switch_Control( $wp_customize, 'edufication_pro_theme_options[event_section_enable]', array(
	'label'             => esc_html__( 'Event Section Enable', 'edufication-pro' ),
	'section'           => 'edufication_pro_event_section',
	'on_off_label' 		=> edufication_pro_switch_options(),
) ) );

// event title setting and control
$wp_customize->add_setting( 'edufication_pro_theme_options[event_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['event_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'edufication_pro_theme_options[event_title]', array(
	'label'           	=> esc_html__( 'Title', 'edufication-pro' ),
	'section'        	=> 'edufication_pro_event_section',
	'active_callback' 	=> 'edufication_pro_is_event_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'edufication_pro_theme_options[event_title]', array(
		'selector'            => '#news-events .section-header h2.section-title',
		'settings'            => 'edufication_pro_theme_options[event_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'edufication_pro_event_title_partial',
    ) );
}

// event btn label setting and control
$wp_customize->add_setting( 'edufication_pro_theme_options[event_btn_label]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['event_btn_label'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'edufication_pro_theme_options[event_btn_label]', array(
	'label'           	=> esc_html__( 'Button Label', 'edufication-pro' ),
	'section'        	=> 'edufication_pro_event_section',
	'active_callback' 	=> 'edufication_pro_is_event_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'edufication_pro_theme_options[event_btn_label]', array(
		'selector'            => '#news-events .more-link a',
		'settings'            => 'edufication_pro_theme_options[event_btn_label]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'edufication_pro_event_btn_label_partial',
    ) );
}

// event btn url setting and control
$wp_customize->add_setting( 'edufication_pro_theme_options[event_btn_link]', array(
	'sanitize_callback' => 'esc_url_raw',
	'default'			=> '#',
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'edufication_pro_theme_options[event_btn_link]', array(
	'label'           	=> esc_html__( 'Button Link', 'edufication-pro' ),
	'section'        	=> 'edufication_pro_event_section',
	'active_callback' 	=> 'edufication_pro_is_event_section_enable',
	'type'				=> 'url',
) );

// Event number control and setting
$wp_customize->add_setting( 'edufication_pro_theme_options[event_count]', array(
	'default'          	=> $options['event_count'],
	'sanitize_callback' => 'edufication_pro_sanitize_number_range',
	'validate_callback' => 'edufication_pro_validate_event_count',
) );

$wp_customize->add_control( 'edufication_pro_theme_options[event_count]', array(
	'label'             => esc_html__( 'Number of Events', 'edufication-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 12. Please input the valid number and save. Then refresh the page to see the change.', 'edufication-pro' ),
	'section'           => 'edufication_pro_event_section',
	'active_callback'   => 'edufication_pro_is_event_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 12,
		'style' => 'width: 100px;'
		),
) );

// event read more label setting and control
$wp_customize->add_setting( 'edufication_pro_theme_options[event_read_more_label]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['event_read_more_label'],
) );

$wp_customize->add_control( 'edufication_pro_theme_options[event_read_more_label]', array(
	'label'           	=> esc_html__( 'Read More Label', 'edufication-pro' ),
	'section'        	=> 'edufication_pro_event_section',
	'active_callback' 	=> 'edufication_pro_is_event_section_enable',
	'type'				=> 'text',
) );

// Event content type control and setting
$wp_customize->add_setting( 'edufication_pro_theme_options[event_content_type]', array(
	'default'          	=> $options['event_content_type'],
	'sanitize_callback' => 'edufication_pro_sanitize_select',
) );

$wp_customize->add_control( 'edufication_pro_theme_options[event_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'edufication-pro' ),
	'section'           => 'edufication_pro_event_section',
	'type'				=> 'select',
	'active_callback' 	=> 'edufication_pro_is_event_section_enable',
	'choices'			=> edufication_pro_event_section_options(),
) );

for ( $i = 1; $i <= $options['event_count']; $i++ ) :

	// event pages drop down chooser control and setting
	$wp_customize->add_setting( 'edufication_pro_theme_options[event_content_page_' . $i . ']', array(
		'sanitize_callback' => 'edufication_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Edufication_Pro_Dropdown_Chooser( $wp_customize, 'edufication_pro_theme_options[event_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'edufication-pro' ), $i ),
		'section'           => 'edufication_pro_event_section',
		'choices'			=> edufication_pro_page_choices(),
		'active_callback'	=> 'edufication_pro_is_event_section_content_page_enable',
	) ) );

	// event posts drop down chooser control and setting
	$wp_customize->add_setting( 'edufication_pro_theme_options[event_content_post_' . $i . ']', array(
		'sanitize_callback' => 'edufication_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Edufication_Pro_Dropdown_Chooser( $wp_customize, 'edufication_pro_theme_options[event_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'edufication-pro' ), $i ),
		'section'           => 'edufication_pro_event_section',
		'choices'			=> edufication_pro_post_choices(),
		'active_callback'	=> 'edufication_pro_is_event_section_content_post_enable',
	) ) );

	// event posts drop down chooser control and setting
	$wp_customize->add_setting( 'edufication_pro_theme_options[event_content_event_' . $i . ']', array(
		'sanitize_callback' => 'absint',
	) );

	$wp_customize->add_control( new Edufication_Pro_Dropdown_Chooser( $wp_customize, 'edufication_pro_theme_options[event_content_event_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Event %d', 'edufication-pro' ), $i ),
		'section'           => 'edufication_pro_event_section',
		'choices'			=> edufication_pro_custom_post_choices( 'tp-event' ),
		'active_callback'	=> 'edufication_pro_is_event_section_content_event_enable',
	) ) );
	
endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'edufication_pro_theme_options[event_content_category]', array(
	'sanitize_callback' => 'edufication_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Edufication_Pro_Dropdown_Taxonomies_Control( $wp_customize,'edufication_pro_theme_options[event_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'edufication-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'edufication-pro' ),
	'section'           => 'edufication_pro_event_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'edufication_pro_is_event_section_content_category_enable'
) ) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'edufication_pro_theme_options[event_content_event_cat]', array(
	'sanitize_callback' => 'absint',
) ) ;

$wp_customize->add_control( new Edufication_Pro_Dropdown_Taxonomies_Control( $wp_customize,'edufication_pro_theme_options[event_content_event_cat]', array(
	'label'             => esc_html__( 'Select Event Category', 'edufication-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of events will be shown from selected event category', 'edufication-pro' ),
	'taxonomy'			=> 'tp-event-category',
	'section'           => 'edufication_pro_event_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'edufication_pro_is_event_section_content_event_category_enable'
) ) );
