<?php
/**
 * Topbar Section options
 *
 * @package Theme Palace
 * @subpackage Edufication Pro
 * @since Edufication Pro 1.0.0
 */

// Add Topbar section
$wp_customize->add_section( 'edufication_pro_topbar_section', array(
	'title'             => esc_html__( 'Topbar','edufication-pro' ),
	'description'       => esc_html__( 'Topbar Section options.', 'edufication-pro' ),
	'panel'             => 'edufication_pro_front_page_panel',
) );

// Topbar content enable control and setting
$wp_customize->add_setting( 'edufication_pro_theme_options[topbar_section_enable]', array(
	'default'			=> 	$options['topbar_section_enable'],
	'sanitize_callback' => 'edufication_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Edufication_Pro_Switch_Control( $wp_customize, 'edufication_pro_theme_options[topbar_section_enable]', array(
	'label'             => esc_html__( 'Topbar Section Enable', 'edufication-pro' ),
	'section'           => 'edufication_pro_topbar_section',
	'on_off_label' 		=> edufication_pro_switch_options(),
) ) );

// topbar email setting and control
$wp_customize->add_setting( 'edufication_pro_theme_options[topbar_news_label]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['topbar_news_label'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'edufication_pro_theme_options[topbar_news_label]', array(
	'label'           	=> esc_html__( 'News Label', 'edufication-pro' ),
	'section'        	=> 'edufication_pro_topbar_section',
	'active_callback' 	=> 'edufication_pro_is_topbar_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'edufication_pro_theme_options[topbar_news_label]', array(
		'selector'            => '#top-header .latest-news .latest-news-header span',
		'settings'            => 'edufication_pro_theme_options[topbar_news_label]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'edufication_pro_topbar_news_label_partial',
    ) );
}

// Topbar news content type control and setting
$wp_customize->add_setting( 'edufication_pro_theme_options[topbar_content_type]', array(
	'default'          	=> $options['topbar_content_type'],
	'sanitize_callback' => 'edufication_pro_sanitize_select',
) );

$wp_customize->add_control( 'edufication_pro_theme_options[topbar_content_type]', array(
	'label'             => esc_html__( 'News Content Type', 'edufication-pro' ),
	'section'           => 'edufication_pro_topbar_section',
	'type'				=> 'select',
	'active_callback' 	=> 'edufication_pro_is_topbar_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'edufication-pro' ),
		'post' 		=> esc_html__( 'Post', 'edufication-pro' ),
		'category' 	=> esc_html__( 'Category', 'edufication-pro' ),
	),
) );

// Topbar news count control and setting
$wp_customize->add_setting( 'edufication_pro_theme_options[topbar_count]', array(
	'default'          	=> $options['topbar_count'],
	'sanitize_callback' => 'edufication_pro_sanitize_number_range',
	'validate_callback' => 'edufication_pro_validate_topbar_count',
) );

$wp_customize->add_control( 'edufication_pro_theme_options[topbar_count]', array(
	'label'             => esc_html__( 'Number of News', 'edufication-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 12. Please input the valid number and save. Then refresh the page to see the change.', 'edufication-pro' ),
	'section'           => 'edufication_pro_topbar_section',
	'active_callback'   => 'edufication_pro_is_topbar_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 12,
		'style' => 'width: 100px;'
		),
) );

for ( $i = 1; $i <= $options['topbar_count']; $i++ ) :
	// topbar pages drop down chooser control and setting
	$wp_customize->add_setting( 'edufication_pro_theme_options[topbar_content_page_' . $i . ']', array(
		'sanitize_callback' => 'edufication_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Edufication_Pro_Dropdown_Chooser( $wp_customize, 'edufication_pro_theme_options[topbar_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'edufication-pro' ), $i ),
		'section'           => 'edufication_pro_topbar_section',
		'choices'			=> edufication_pro_page_choices(),
		'active_callback'	=> 'edufication_pro_is_topbar_news_content_page_enable',
	) ) );

	// topbar posts drop down chooser control and setting
	$wp_customize->add_setting( 'edufication_pro_theme_options[topbar_content_post_' . $i . ']', array(
		'sanitize_callback' => 'edufication_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Edufication_Pro_Dropdown_Chooser( $wp_customize, 'edufication_pro_theme_options[topbar_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'edufication-pro' ), $i ),
		'section'           => 'edufication_pro_topbar_section',
		'choices'			=> edufication_pro_post_choices(),
		'active_callback'	=> 'edufication_pro_is_topbar_news_content_post_enable',
	) ) );
endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'edufication_pro_theme_options[topbar_content_category]', array(
	'sanitize_callback' => 'edufication_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Edufication_Pro_Dropdown_Taxonomies_Control( $wp_customize,'edufication_pro_theme_options[topbar_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'edufication-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'edufication-pro' ),
	'section'           => 'edufication_pro_topbar_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'edufication_pro_is_topbar_news_content_category_enable'
) ) );

// topbar hr setting and control
$wp_customize->add_setting( 'edufication_pro_theme_options[topbar_hr]', array(
	'sanitize_callback' => 'sanitize_text_field'
) );

$wp_customize->add_control( new Edufication_Pro_Customize_Horizontal_Line( $wp_customize, 'edufication_pro_theme_options[topbar_hr]',
	array(
		'section'         => 'edufication_pro_topbar_section',
		'active_callback' => 'edufication_pro_is_topbar_section_enable',
		'type'			  => 'hr'
) ) );

// top bar menu visible
$wp_customize->add_setting( 'edufication_pro_theme_options[topbar_social_enable]',
	array(
		'default'       	=> $options['topbar_social_enable'],
		'sanitize_callback' => 'edufication_pro_sanitize_switch_control',
	)
);
$wp_customize->add_control( new Edufication_Pro_Switch_Control( $wp_customize, 'edufication_pro_theme_options[topbar_social_enable]',
    array(
		'label'      		=> esc_html__( 'Display Social Menu', 'edufication-pro' ),
		'description'       => sprintf( '%1$s <a class="topbar-menu-trigger" href="#"> %2$s </a> %3$s', esc_html__( 'Note: To show topbar social menu.', 'edufication-pro' ), esc_html__( 'Click Here', 'edufication-pro' ), esc_html__( 'to create menu', 'edufication-pro' ) ),
		'section'    		=> 'edufication_pro_topbar_section',
		'active_callback'	=> 'edufication_pro_is_topbar_section_enable',
		'on_off_label' 		=> edufication_pro_switch_options(),
    )
) );

// topbar email setting and control
$wp_customize->add_setting( 'edufication_pro_theme_options[topbar_email]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['topbar_email'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'edufication_pro_theme_options[topbar_email]', array(
	'label'           	=> esc_html__( 'Email ID', 'edufication-pro' ),
	'section'        	=> 'edufication_pro_topbar_section',
	'active_callback' 	=> 'edufication_pro_is_topbar_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'edufication_pro_theme_options[topbar_email]', array(
		'selector'            => '#top-header .contact-info .topbar-email a',
		'settings'            => 'edufication_pro_theme_options[topbar_email]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'edufication_pro_topbar_email_partial',
    ) );
}

// topbar phone setting and control
$wp_customize->add_setting( 'edufication_pro_theme_options[topbar_phone]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['topbar_phone'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'edufication_pro_theme_options[topbar_phone]', array(
	'label'           	=> esc_html__( 'Phone No.', 'edufication-pro' ),
	'section'        	=> 'edufication_pro_topbar_section',
	'active_callback' 	=> 'edufication_pro_is_topbar_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'edufication_pro_theme_options[topbar_phone]', array(
		'selector'            => '#top-header .contact-info .topbar-phone a',
		'settings'            => 'edufication_pro_theme_options[topbar_phone]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'edufication_pro_topbar_phone_partial',
    ) );
}