<?php
/**
 * Theme Palace options
 *
 * @package Theme Palace
 * @subpackage Edufication Pro
 * @since Edufication Pro 1.0.0
 */

/**
 * List of pages for page choices.
 * @return Array Array of page ids and name.
 */
function edufication_pro_page_choices() {
    $pages = get_pages();
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'edufication-pro' );
    foreach ( $pages as $page ) {
        $choices[ $page->ID ] = $page->post_title;
    }
    return  $choices;
}

/**
 * List of posts for post choices.
 * @return Array Array of post ids and name.
 */
function edufication_pro_post_choices() {
    $posts = get_posts( array( 'numberposts' => -1 ) );
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'edufication-pro' );
    foreach ( $posts as $post ) {
        $choices[ $post->ID ] = $post->post_title;
    }
    return  $choices;
}

/**
 * List of posts for custom post choices.
 * @return Array Array of post ids and name.
 */
function edufication_pro_custom_post_choices( $post_type ) {
    $args = array(
        'post_type'         => $post_type,
        'posts_per_page'    => -1,
    );
    $posts = get_posts( $args );
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'edufication-pro' );
    foreach ( $posts as $post ) {
        $choices[ $post->ID ] = $post->post_title;
    }
    return  $choices;
}

if ( ! function_exists( 'edufication_pro_typography_options' ) ) :
    /**
     * Returns list of typography
     * @return array font styles
     */
    function edufication_pro_typography_options(){
        $choices = array(
            'default'         => esc_html__( 'Default', 'edufication-pro' ),
            'header-font-1'   => esc_html__( 'Montserrat', 'edufication-pro' ),
            'header-font-2'   => esc_html__( 'Playfair Display', 'edufication-pro' ),
            'header-font-3'   => esc_html__( 'Poppins', 'edufication-pro' ),
            'header-font-4'   => esc_html__( 'Raleway', 'edufication-pro' ),
            'header-font-5'   => esc_html__( 'Ubuntu', 'edufication-pro' ),
        );

        $output = apply_filters( 'edufication_pro_typography_options', $choices );
        if ( ! empty( $output ) ) {
            ksort( $output );
        }

        return $output;
    }
endif;


if ( ! function_exists( 'edufication_pro_body_typography_options' ) ) :
    /**
     * Returns list of typography
     * @return array font styles
     */
    function edufication_pro_body_typography_options(){
        $choices = array(
            'default'         => esc_html__( 'Default', 'edufication-pro' ),
            'body-font-1'     => esc_html__( 'EB Garamond', 'edufication-pro' ),
            'body-font-2'     => esc_html__( 'Nunito', 'edufication-pro' ),
            'body-font-3'     => esc_html__( 'Oxygen', 'edufication-pro' ),
            'body-font-4'     => esc_html__( 'Philosopher', 'edufication-pro' ),
            'body-font-5'     => esc_html__( 'Quattrocento', 'edufication-pro' ),
        );

        $output = apply_filters( 'edufication_pro_body_typography_options', $choices );
        if ( ! empty( $output ) ) {
            ksort( $output );
        }

        return $output;
    }
endif;


if ( ! function_exists( 'edufication_pro_site_layout' ) ) :
    /**
     * Site Layout
     * @return array site layout options
     */
    function edufication_pro_site_layout() {
        $edufication_pro_site_layout = array(
            'wide'  => get_template_directory_uri() . '/assets/images/full.png',
            'boxed-layout' => get_template_directory_uri() . '/assets/images/boxed.png',
            'frame-layout' => get_template_directory_uri() . '/assets/images/frame.png',
        );

        $output = apply_filters( 'edufication_pro_site_layout', $edufication_pro_site_layout );
        return $output;
    }
endif;

if ( ! function_exists( 'edufication_pro_selected_sidebar' ) ) :
    /**
     * Sidebars options
     * @return array Sidbar positions
     */
    function edufication_pro_selected_sidebar() {
        $edufication_pro_selected_sidebar = array(
            'sidebar-1'             => esc_html__( 'Default Sidebar', 'edufication-pro' ),
            'optional-sidebar'      => esc_html__( 'Optional Sidebar 1', 'edufication-pro' ),
            'optional-sidebar-2'    => esc_html__( 'Optional Sidebar 2', 'edufication-pro' ),
            'optional-sidebar-3'    => esc_html__( 'Optional Sidebar 3', 'edufication-pro' ),
            'optional-sidebar-4'    => esc_html__( 'Optional Sidebar 4', 'edufication-pro' ),
        );

        $output = apply_filters( 'edufication_pro_selected_sidebar', $edufication_pro_selected_sidebar );

        return $output;
    }
endif;


if ( ! function_exists( 'edufication_pro_sidebar_position' ) ) :
    /**
     * Sidebar position
     * @return array Sidbar positions
     */
    function edufication_pro_sidebar_position() {
        $edufication_pro_sidebar_position = array(
            'right-sidebar' => get_template_directory_uri() . '/assets/images/right.png',
            'left-sidebar'  => get_template_directory_uri() . '/assets/images/left.png',
            'no-sidebar'    => get_template_directory_uri() . '/assets/images/full.png',
            'no-sidebar-content'   => get_template_directory_uri() . '/assets/images/boxed.png',
        );

        $output = apply_filters( 'edufication_pro_sidebar_position', $edufication_pro_sidebar_position );

        return $output;
    }
endif;

if ( ! function_exists( 'edufication_pro_pagination_options' ) ) :
    /**
     * Pagination
     * @return array site pagination options
     */
    function edufication_pro_pagination_options() {
        $edufication_pro_pagination_options = array(
            'numeric'   => esc_html__( 'Numeric', 'edufication-pro' ),
            'default'   => esc_html__( 'Default(Older/Newer)', 'edufication-pro' ),
            'infinite'  => esc_html__( 'Infinite', 'edufication-pro' ),
        );

        $output = apply_filters( 'edufication_pro_pagination_options', $edufication_pro_pagination_options );

        return $output;
    }
endif;

if ( ! function_exists( 'edufication_pro_get_spinner_list' ) ) :
    /**
     * List of spinner icons options.
     * @return array List of all spinner icon options.
     */
    function edufication_pro_get_spinner_list() {
        $arr = array(
            'default'               => esc_html__( 'Default', 'edufication-pro' ),
            'spinner-wheel'         => esc_html__( 'Wheel', 'edufication-pro' ),
            'spinner-double-circle' => esc_html__( 'Double Circle', 'edufication-pro' ),
            'spinner-two-way'       => esc_html__( 'Two Way', 'edufication-pro' ),
            'spinner-umbrella'      => esc_html__( 'Umbrella', 'edufication-pro' ),
            'spinner-circle'        => esc_html__( 'Circle', 'edufication-pro' ),
            'spinner-dots'          => esc_html__( 'Dots', 'edufication-pro' ),
            'spinner-one-way'       => esc_html__( 'One Way', 'edufication-pro' ),
            'spinner-fidget'        => esc_html__( 'Fidget', 'edufication-pro' ),
        );
        return apply_filters( 'edufication_pro_spinner_list', $arr );
    }
endif;

if ( ! function_exists( 'edufication_pro_switch_options' ) ) :
    /**
     * List of custom Switch Control options
     * @return array List of switch control options.
     */
    function edufication_pro_switch_options() {
        $arr = array(
            'on'        => esc_html__( 'Enable', 'edufication-pro' ),
            'off'       => esc_html__( 'Disable', 'edufication-pro' )
        );
        return apply_filters( 'edufication_pro_switch_options', $arr );
    }
endif;

if ( ! function_exists( 'edufication_pro_hide_options' ) ) :
    /**
     * List of custom Switch Control options
     * @return array List of switch control options.
     */
    function edufication_pro_hide_options() {
        $arr = array(
            'on'        => esc_html__( 'Yes', 'edufication-pro' ),
            'off'       => esc_html__( 'No', 'edufication-pro' )
        );
        return apply_filters( 'edufication_pro_hide_options', $arr );
    }
endif;

if ( ! function_exists( 'edufication_pro_sortable_sections' ) ) :
    /**
     * List of sections Control options
     * @return array List of Sections control options.
     */
    function edufication_pro_sortable_sections() {
        $sections = array(
            'banner'    => esc_html__( 'Banner', 'edufication-pro' ),
            'service'   => esc_html__( 'Services', 'edufication-pro' ),
            'about'     => esc_html__( 'About Us', 'edufication-pro' ),
            'course'    => esc_html__( 'Courses', 'edufication-pro' ),
            'subscribe' => esc_html__( 'Subscribe and CountDown', 'edufication-pro' ),
            'event'     => esc_html__( 'Events', 'edufication-pro' ),
            'testimonial' => esc_html__( 'Testimonial', 'edufication-pro' ),
            'team'      => esc_html__( 'Team', 'edufication-pro' ),
            'cta'       => esc_html__( 'Call to Action', 'edufication-pro' ),
            'blog'      => esc_html__( 'Blog', 'edufication-pro' ),
        );
        return apply_filters( 'edufication_pro_sortable_sections', $sections );
    }
endif;

if ( ! function_exists( 'edufication_pro_course_section_options' ) ) :
    /**
     * Pagination
     * @return array site course_section options
     */
    function edufication_pro_course_section_options() {
        $edufication_pro_course_section_options = array(
            'page'      => esc_html__( 'Page', 'edufication-pro' ),
            'post'      => esc_html__( 'Post', 'edufication-pro' ),
            'category'  => esc_html__( 'Category', 'edufication-pro' ),
        );

        if ( class_exists( 'TP_Education' ) ) {
             
               $custom_choice = array();
               if ( post_type_exists('tp-course') ){
                $custom_choice['tp-course'] = esc_html__( 'Course', 'edufication-pro' );
                $custom_choice['tp-course-cat'] = esc_html__( 'Course Category', 'edufication-pro' );
                $custom_choice['recent-tp-course'] = esc_html__( 'Recent Course', 'edufication-pro' );
               }
        }else{
             $custom_choice = array();
        }
        $edufication_pro_course_section_options = array_merge( $edufication_pro_course_section_options, $custom_choice);

        $output = apply_filters( 'edufication_pro_course_section_options', $edufication_pro_course_section_options );

        return $output;
    }
endif;

if ( ! function_exists( 'edufication_pro_event_section_options' ) ) :
    /**
     * Pagination
     * @return array site event_section options
     */
    function edufication_pro_event_section_options() {
        $edufication_pro_event_section_options = array(
            'page'      => esc_html__( 'Page', 'edufication-pro' ),
            'post'      => esc_html__( 'Post', 'edufication-pro' ),
            'category'  => esc_html__( 'Category', 'edufication-pro' ),
        );

        if ( class_exists( 'TP_Education' ) ) {
                
                $custom_choice = array();
                if( post_type_exists('tp-event') ){
                    $custom_choice['tp-event'] = esc_html__('Events', 'edufication-pro');
                    $custom_choice['tp-event-cat'] = esc_html__('Events Category', 'edufication-pro');
                    $custom_choice['recent-tp-event'] = esc_html__('Recent Events', 'edufication-pro');
                }

        }else{
             $custom_choice = array();
        }
        $edufication_pro_event_section_options = array_merge( $edufication_pro_event_section_options,  $custom_choice );

        $output = apply_filters( 'edufication_pro_event_section_options', $edufication_pro_event_section_options );

        return $output;
    }
endif;

if ( ! function_exists( 'edufication_pro_testimonial_section_options' ) ) :
    /**
     * Pagination
     * @return array site testimonial_section options
     */
    function edufication_pro_testimonial_section_options() {
        $edufication_pro_testimonial_section_options = array(
            'page'      => esc_html__( 'Page', 'edufication-pro' ),
            'post'      => esc_html__( 'Post', 'edufication-pro' ),
            'category'  => esc_html__( 'Category', 'edufication-pro' ),
        );

        if ( class_exists( 'TP_Education' ) ) {

         $custom_choice = array();
         if ( post_type_exists('tp-testimonial') ){
            $custom_choice['tp-testimonial'] = esc_html__( 'Testimonial', 'edufication-pro' );
            $custom_choice['recent-tp-testimonial'] = esc_html__( 'Recent Testimonial', 'edufication-pro' );
        }
    }else{
             $custom_choice = array();
        }
    $edufication_pro_testimonial_section_options = array_merge( $edufication_pro_testimonial_section_options, $custom_choice );

    $output = apply_filters( 'edufication_pro_testimonial_section_options', $edufication_pro_testimonial_section_options );

        return $output;
    }
endif;

if ( ! function_exists( 'edufication_pro_team_section_options' ) ) :
    /**
     * Pagination
     * @return array site team_section options
     */
    function edufication_pro_team_section_options() {
        $edufication_pro_team_section_options = array(
            'page'      => esc_html__( 'Page', 'edufication-pro' ),
            'post'      => esc_html__( 'Post', 'edufication-pro' ),
            'category'  => esc_html__( 'Category', 'edufication-pro' ),
            );

        if ( class_exists( 'TP_Education' ) ) {
            $custom_choice = array();
            if(post_type_exists('tp-team')){
                $custom_choice['tp-team'] = esc_html__( 'Teams', 'edufication-pro' );
                $custom_choice['tp-team-cat'] = esc_html__( 'Teams Category', 'edufication-pro' );
                $custom_choice['recent-tp-team'] = esc_html__( 'Recent Teams', 'edufication-pro' );
            }
        }else{
             $custom_choice = array();
        }
        $edufication_pro_team_section_options = array_merge( $edufication_pro_team_section_options, $custom_choice);

        $output = apply_filters( 'edufication_pro_team_section_options', $edufication_pro_team_section_options );

        return $output;
    }
endif;