<?php
/**
 * Event section
 *
 * This is the template for the content of event section
 *
 * @package Theme Palace
 * @subpackage Edufication Pro
 * @since Edufication Pro 1.0.0
 */
if ( ! function_exists( 'edufication_pro_add_event_section' ) ) :
    /**
    * Add event section
    *
    *@since Edufication Pro 1.0.0
    */
    function edufication_pro_add_event_section() {
    	$options = edufication_pro_get_theme_options();
        // Check if event is enabled on frontpage
        $event_enable = apply_filters( 'edufication_pro_section_status', true, 'event_section_enable' );

        if ( true !== $event_enable ) {
            return false;
        }
        // Get event section details
        $section_details = array();
        $section_details = apply_filters( 'edufication_pro_filter_event_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render event section now.
        edufication_pro_render_event_section( $section_details );
    }
endif;

if ( ! function_exists( 'edufication_pro_get_event_section_details' ) ) :
    /**
    * event section details.
    *
    * @since Edufication Pro 1.0.0
    * @param array $input event section details.
    */
    function edufication_pro_get_event_section_details( $input ) {
        $options = edufication_pro_get_theme_options();

        // Content type.
        $event_content_type  = $options['event_content_type'];
        $event_count = ! empty( $options['event_count'] ) ? $options['event_count'] : 6;
        
        $content = array();
        switch ( $event_content_type ) {
        	
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $event_count; $i++ ) {
                    if ( ! empty( $options['event_content_page_' . $i] ) )
                        $page_ids[] = $options['event_content_page_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $event_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $event_count; $i++ ) {
                    if ( ! empty( $options['event_content_post_' . $i] ) )
                        $post_ids[] = $options['event_content_post_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $event_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['event_content_category'] ) ? $options['event_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $event_count ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'tp-event':
                $post_ids = array();

                for ( $i = 1; $i <= $event_count; $i++ ) {
                    if ( ! empty( $options['event_content_event_' . $i] ) )
                        $post_ids[] = $options['event_content_event_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'tp-event',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $event_count ),
                    'orderby'           => 'post__in',
                    );                      
            break;

            case 'tp-event-cat':
                $cat_id = ! empty( $options['event_content_event_cat'] ) ? $options['event_content_event_cat'] : '';
                $args = array(
                    'post_type'         => 'tp-event',
                    'posts_per_page'    => absint( $event_count ),
                    'tax_query'         => array(
                        array(
                            'taxonomy'  => 'tp-event-category',
                            'field'     => 'id',
                            'terms'     => absint( $cat_id ),
                        )
                    ) );                    
            break;

            case 'recent-tp-event':
                $args = array(
                    'post_type'         => 'tp-event',
                    'posts_per_page'    => absint( $event_count ),
                    );                    
            break;

            default:
            break;
        }

        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            $i = 1;
            while ( $query->have_posts() ) : $query->the_post();
                $count = ( 1 === $i ) ? 20 : 10;
                $page_post['id']        = get_the_id();
                $page_post['title']     = get_the_title();
                $page_post['url']       = get_the_permalink();
                $page_post['excerpt']   = edufication_pro_trim_content( $count );
                $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'post-thumbnail' ) : '';
                // Push to the main array.
                array_push( $content, $page_post );
            $i++;
            endwhile;
        endif;
        wp_reset_postdata();

            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// event section content details.
add_filter( 'edufication_pro_filter_event_section_details', 'edufication_pro_get_event_section_details' );


if ( ! function_exists( 'edufication_pro_render_event_section' ) ) :
  /**
   * Start event section
   *
   * @return string event content
   * @since Edufication Pro 1.0.0
   *
   */
   function edufication_pro_render_event_section( $content_details = array() ) {
        $options = edufication_pro_get_theme_options();
        $event_content_type  = $options['event_content_type'];
        $btn_link = ! empty( $options['event_btn_link'] ) ? $options['event_btn_link'] : '#';
        $readmore = ! empty( $options['event_read_more_label'] ) ? $options['event_read_more_label'] : esc_html__( 'View Our Event', 'edufication-pro' );

        if ( empty( $content_details ) ) {
            return;
        } ?>

        <div id="news-events" class="relative page-section">
                <div class="wrapper">
                    <?php if ( ! empty( $options['event_title'] ) ) : ?>
                        <div class="section-header text-center">
                            <h2 class="section-title separator"><?php echo esc_html( $options['event_title'] ); ?></h2>
                        </div><!-- .section-header -->
                    <?php endif; ?>

                    <div class="section-content clear">
                        <?php foreach ( $content_details as $content ) : ?>
                            <article class="<?php echo ! empty( $content['image'] ) ? 'has-post-thumbnail' : 'no-post-thumbnail'; ?>">
                                
                                <div class="featured-image" <?php if ( ! empty( $content['image'] ) ) : ?> style="background-image: url('<?php echo esc_url( $content['image'] ); ?>');" <?php endif; ?>>
                                    <?php if ( ! empty( $content['image'] ) ) : ?>
                                        <a href="<?php echo esc_url( $content['url'] ); ?>" class="featured-image-link"></a>
                                    <?php endif; ?>
                                    <span class="posted-on">
                                        <time><?php echo date_i18n( 'd', strtotime( get_the_date( '', $content['id'] ) ) ); ?> <span class="month"><?php echo date_i18n( 'M', strtotime( get_the_date( '', $content['id'] ) ) ); ?></span></time>
                                    </span><!-- .posted-on -->
                                </div>
                                

                                <div class="entry-container">
                                    <header class="entry-header">
                                        <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                    </header>

                                    <?php if ( class_exists( 'TP_Education' ) &&  in_array( $event_content_type, array( 'tp-event', 'tp-event-cat', 'recent-tp-event' ) ) ) : ?>
                                        <div class="entry-meta">
                                            <span class="posted-on">
                                                <time>
                                                    <?php 
                                                        echo edufication_pro_get_svg( array( 'icon' => 'time' ) );
                                                        tp_event_start_time( $content['id'] );
                                                        echo ' - ';
                                                        tp_event_end_time( $content['id'] );
                                                    ?>
                                                </time>
                                            </span><!-- .posted-on -->

                                            <span class="cat-links">
                                                <?php echo edufication_pro_get_svg( array( 'icon' => 'plane' ) ); ?>
                                                <a href="<?php echo esc_url( $content['url'] ); ?>"><?php tp_event_location( $content['id'] ); ?></a>
                                            </span><!-- .cat-links -->
                                        </div><!-- .entry-meta -->
                                    <?php endif; ?>

                                    <div class="entry-content">
                                        <p><?php echo esc_html( $content['excerpt'] ); ?></p>
                                    </div><!-- .entry-content -->

                                    <a href="<?php echo esc_url( $content['url'] ); ?>" class="view-event"><?php echo esc_html( $readmore ); ?></a>
                                </div><!-- .entry-container -->
                            </article>
                        <?php endforeach; ?>
                    </div><!-- .section-content -->
                    <?php if ( ! empty( $options['event_btn_label'] ) ) : ?>
                        <div class="more-link text-center">
                            <a href="<?php echo esc_url( $btn_link ); ?>" class="btn btn-default"><?php echo esc_html( $options['event_btn_label'] ); ?></a>
                        </div><!-- .more-link -->
                    <?php endif; ?>
                </div><!-- .wrapper -->
            </div><!-- #news-events -->

    <?php }
endif;