<?php
/**
 * Service section
 *
 * This is the template for the content of service section
 *
 * @package Theme Palace
 * @subpackage Edufication Pro
 * @since Edufication Pro 1.0.0
 */
if ( ! function_exists( 'edufication_pro_add_service_section' ) ) :
    /**
    * Add service section
    *
    *@since Edufication Pro 1.0.0
    */
    function edufication_pro_add_service_section() {
    	$options = edufication_pro_get_theme_options();
        // Check if service is enabled on frontpage
        $service_enable = apply_filters( 'edufication_pro_section_status', true, 'service_section_enable' );

        if ( true !== $service_enable ) {
            return false;
        }
        // Get service section details
        $section_details = array();
        $section_details = apply_filters( 'edufication_pro_filter_service_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render service section now.
        edufication_pro_render_service_section( $section_details );
    }
endif;

if ( ! function_exists( 'edufication_pro_get_service_section_details' ) ) :
    /**
    * service section details.
    *
    * @since Edufication Pro 1.0.0
    * @param array $input service section details.
    */
    function edufication_pro_get_service_section_details( $input ) {
        $options = edufication_pro_get_theme_options();

        // Content type.
        $service_content_type  = $options['service_content_type'];
        $service_count = ! empty( $options['service_count'] ) ? $options['service_count'] : 4;
        
        $content = array();
        switch ( $service_content_type ) {
        	
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $service_count; $i++ ) {
                    if ( ! empty( $options['service_content_page_' . $i] ) )
                        $page_ids[] = $options['service_content_page_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $service_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $service_count; $i++ ) {
                    if ( ! empty( $options['service_content_post_' . $i] ) )
                        $post_ids[] = $options['service_content_post_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $service_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['service_content_category'] ) ? $options['service_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $service_count ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            default:
            break;
        }


            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['title']     = get_the_title();
                    $page_post['url']       = get_the_permalink();
                    $page_post['excerpt']   = edufication_pro_trim_content( 13 );

                    // Push to the main array.
                    array_push( $content, $page_post );
                endwhile;
            endif;
            wp_reset_postdata();

            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// service section content details.
add_filter( 'edufication_pro_filter_service_section_details', 'edufication_pro_get_service_section_details' );


if ( ! function_exists( 'edufication_pro_render_service_section' ) ) :
  /**
   * Start service section
   *
   * @return string service content
   * @since Edufication Pro 1.0.0
   *
   */
   function edufication_pro_render_service_section( $content_details = array() ) {
        $options = edufication_pro_get_theme_options();
        $layout = ! empty( $options['service_column'] ) ? $options['service_column'] : 2;
        $btn_link = ! empty( $options['service_btn_link'] ) ? $options['service_btn_link'] : '#';

        if ( empty( $content_details ) ) {
            return;
        } ?>

        <div id="our-services" class="relative page-section col-<?php echo absint( $layout ); ?>">
            <div class="our-services-wrapper">
                <div class="wrapper">
                    <div class="services-wrapper">
                        <?php if ( ! empty( $options['service_title'] ) || ! empty( $options['service_description'] ) ) : ?>
                            <div class="hentry services-section-content">
                                <?php if ( ! empty( $options['service_title'] ) ) : ?>
                                    <div class="section-header">
                                        <h2 class="section-title separator"><?php echo esc_html( $options['service_title'] ); ?></h2>
                                    </div><!-- .section-content -->
                                <?php endif; 

                                if ( ! empty( $options['service_description'] ) ) : ?>
                                    <div class="section-content">
                                        <p><?php echo wp_kses_post( $options['service_description'] ); ?></p>
                                    </div><!-- .section-content -->
                                <?php endif; 

                                if ( ! empty( $options['service_btn_label'] ) ) : ?>
                                    <div class="more-link">
                                        <a href="<?php echo esc_url( $btn_link ); ?>" class="btn btn-default"><?php echo esc_html( $options['service_btn_label'] ); ?></a>
                                    </div><!-- .more-link -->
                                <?php endif; ?>
                            </div><!-- .hentry -->
                        <?php endif; ?>

                        <div class="hentry services-items-wrapper col-2">
                            <?php foreach ( $content_details as $content ) : ?>
                                <article>
                                    <header class="entry-header">
                                        <h2 class="entry-title">
                                            <a href="<?php echo esc_url( $content['url'] ); ?>">
                                                <?php 
                                                echo edufication_pro_get_svg( array( 'icon' => 'check' ) );
                                                echo esc_html( $content['title'] ); 
                                                ?>
                                            </a>
                                        </h2>
                                    </header>

                                    <div class="entry-content">
                                        <p><?php echo esc_html( $content['excerpt'] ); ?></p>
                                    </div><!-- .entry-content -->
                                </article>
                            <?php endforeach; ?>
                        </div><!-- .hentry -->
                    </div><!-- .services-wrapper -->
                    
                    <?php if ( ! empty( $options['service_btn_label'] ) ) : ?>
                        <div class="more-link">
                            <a href="<?php echo esc_url( $btn_link ); ?>" class="btn btn-default"><?php echo esc_html( $options['service_btn_label'] ); ?></a>
                        </div><!-- .more-link -->
                    <?php endif; ?>
                </div><!-- .wrapper -->
            </div><!-- .our-services-wrapper -->
        </div><!-- #our-services -->
    <?php }
endif;