<?php
/**
 * Subscribe section
 *
 * This is the template for the content of subscribe section
 *
 * @package Theme Palace
 * @subpackage Edufication Pro
 * @since Edufication Pro 1.0.0
 */
if ( ! function_exists( 'edufication_pro_add_subscribe_section' ) ) :
    /**
    * Add subscribe section
    *
    *@since Edufication Pro 1.0.0
    */
    function edufication_pro_add_subscribe_section() {
    	$options = edufication_pro_get_theme_options();
        // Check if subscribe is enabled on frontpage
        $subscribe_enable = apply_filters( 'edufication_pro_section_status', true, 'subscribe_section_enable' );

        if ( true !== $subscribe_enable ) {
            return false;
        }

        // Render subscribe section now.
        edufication_pro_render_subscribe_section();
    }
endif;

if ( ! function_exists( 'edufication_pro_render_subscribe_section' ) ) :
  /**
   * Start subscribe section
   *
   * @return string subscribe content
   * @since Edufication Pro 1.0.0
   *
   */
   function edufication_pro_render_subscribe_section() {
        $options = edufication_pro_get_theme_options();
        $background = ! empty( $options['subscribe_image'] ) ? $options['subscribe_image'] : get_template_directory_uri() . '/assets/uploads/subscribe-newsletter-bg.jpg';
        $subscription_title = ! empty( $options['subscription_title'] ) ? $options['subscription_title'] : '';
        $column = ( $options['subscribe_enable'] && class_exists( 'Jetpack' ) && Jetpack::is_module_active( 'subscriptions' ) ) ? 'col-2' : 'col-1';
        ?>
        
        <!-- .supports col-1 and col-2 -->
        <div id="subscribe-newsletter" class="relative page-section <?php echo esc_attr( $column ); ?>" style="background-image: url('<?php echo esc_url( $background ); ?>');">
            <div class="overlay"></div>
            <div class="wrapper">
                <div class="hentry">
                    <?php if ( ! empty( $options['subscribe_section_title'] ) || ! empty( $options['subscribe_section_sub_title'] ) ) : ?>
                        <div class="section-header">
                            <?php if ( ! empty( $options['subscribe_section_title'] ) ) : ?>
                                <h3 class="section-subtitle"><?php echo esc_html( $options['subscribe_section_title'] ); ?></h3>
                            <?php endif; 

                            if ( ! empty( $options['subscribe_section_sub_title'] ) ) : ?>
                                <h2 class="section-title"><?php echo esc_html( $options['subscribe_section_sub_title'] ); ?></h2>
                            <?php endif; ?>
                        </div><!-- .section-header -->
                    <?php endif; 

                    if ( $options['count_down_enable'] && ! empty( $options['count_down_date'] ) ) : ?>
                        <div class="course-starting-time">
                            <h4 id="courses-timer" data-countdown="<?php echo esc_attr( $options['count_down_date'] ); ?>"></h4>
                        </div><!-- .course-starting-time -->
                    <?php endif; ?>
                </div><!-- .hentry -->

                <?php if ( $options['subscribe_enable'] && class_exists( 'Jetpack' ) && Jetpack::is_module_active( 'subscriptions' ) ) : ?>
                    <div class="hentry">
                        <?php 
                        $subscription_shortcode = '[jetpack_subscription_form title="" subscribe_text="' . esc_html( $subscription_title ) . '" subscribe_button="' . esc_html__( 'Get it now', 'edufication-pro' ) . '" show_subscribers_total=""]';
                        echo do_shortcode( wp_kses_post( $subscription_shortcode ) ); 
                        ?>
                    </div><!-- .hentry -->
                <?php endif; ?>
            </div><!-- .wrapper -->
        </div><!-- #subscribe-newsletter -->

    <?php }
endif;